@@ -8,7 +8,7 @@ from django.contrib.contenttypes.models import ContentType
 from django.forms.utils import ErrorList
 from django.template.defaultfilters import filesizeformat
 from django.utils.safestring import mark_safe
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.urls import reverse
 
 from tendenci.libs.tinymce.widgets import TinyMCE
