@@ -2,7 +2,7 @@ from datetime import datetime
 from datetime import timedelta
 from decimal import Decimal
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django import forms
 from django.contrib.contenttypes.models import ContentType
 from django.forms.utils import ErrorList
