@@ -3,12 +3,12 @@ from datetime import datetime
 
 from django.contrib import admin, messages
 from django.urls import reverse
-from django.conf.urls import url
+from django.urls import path, re_path
 from django.http import HttpResponse, Http404, HttpResponseRedirect
 from django.shortcuts import redirect, get_object_or_404
 from django.utils.encoding import iri_to_uri
 from django.template.defaultfilters import slugify
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.utils.safestring import mark_safe
 
 from tendenci.apps.theme.shortcuts import themed_response as render_to_resp
@@ -248,7 +248,7 @@ class CustomRegFormAdmin(admin.ModelAdmin):
         """
         urls = super(CustomRegFormAdmin, self).get_urls()
         extra_urls = [
-            url(r'^export/(?P<regform_id>\d+)/$',
+            re_path(r'^export/(?P<regform_id>\d+)/$',
                 self.admin_site.admin_view(self.export_view),
                 name="customregform_export"),
         ]
@@ -265,7 +265,7 @@ class StandardRegFormAdmin(admin.ModelAdmin):
         """
         urls = super(StandardRegFormAdmin, self).get_urls()
         extra_urls = [
-            url(r'^edit',
+            re_path(r'^edit',
                 self.admin_site.admin_view(self.edit_regform_view),
                 name="standardregform_edit"),
         ]
