@@ -8,7 +8,7 @@ from django.db import models
 from django.db.models import Q
 from django.contrib.auth.models import AnonymousUser, User
 from django.template import Node, Library, TemplateSyntaxError, Variable
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from tendenci.apps.events.models import Event, Registrant, Type
 from tendenci.apps.events.utils import (registration_earliest_time,
