@@ -68,7 +68,7 @@ class Migration(migrations.Migration):
                 ('send_email', models.BooleanField(default=False, help_text='If checked, the person submitting the form will be sent an email.', verbose_name='Send email')),
                 ('email_from', models.EmailField(help_text='Used as the Reply-to email address in the email to the submitter.', max_length=254, verbose_name='Reply-To address', blank=True)),
                 ('email_copies', models.CharField(help_text='One or more email addresses for form recipients, separated by commas', max_length=2000, verbose_name='Send copies to', blank=True)),
-                ('completion_url', models.CharField(help_text='Redirect to this page after form completion. Absolute URLS should begin with http. Relative URLs should begin with a forward slash (/).', max_length=1000, null=True, verbose_name='Completion URL', blank=True)),
+                ('completion_url', models.CharField(help_text='Optionally, redirect to this page after form completion. Absolute URLS should begin with http. Relative URLs should begin with a forward slash (/).', max_length=1000, null=True, verbose_name='Completion URL', blank=True)),
                 ('template', models.CharField(max_length=50, verbose_name='Template', blank=True)),
                 ('custom_payment', models.BooleanField(default=False, help_text='If checked, please add pricing options below. Leave the price blank if users can enter their own amount.', verbose_name='Is Custom Payment')),
                 ('recurring_payment', models.BooleanField(default=False, help_text="If checked, please add pricing options below. Leave the price blank if users can enter their own amount. Please also add an email field as a required field with type 'email'", verbose_name='Is Recurring Payment')),
@@ -86,6 +86,7 @@ class Migration(migrations.Migration):
             options={
                 'verbose_name': 'Form',
                 'verbose_name_plural': 'Forms',
+                'ordering': ('-id',),
             },
         ),
         migrations.CreateModel(
