@@ -1,5 +1,5 @@
 from django import forms
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from tendenci.apps.help_files.models import Request, HelpFile
 from tendenci.libs.tinymce.widgets import TinyMCE
