@@ -11,8 +11,7 @@ from django.db import models
 from django.urls import reverse
 from django.contrib.sites.models import Site
 from django.conf import settings
-from django.utils.translation import ugettext_lazy as _, ugettext
-from django.utils.encoding import python_2_unicode_compatible
+from django.utils.translation import gettext_lazy as _, ugettext
 from django.contrib.auth.models import User
 
 try:
@@ -21,7 +20,6 @@ except ImportError:
     from datetime import datetime as timezone
 from tendenci.apps.site_settings.utils import get_setting
 
-@python_2_unicode_compatible
 class Queue(models.Model):
     """
     A queue is a collection of tickets into what would generally be business
@@ -535,7 +533,6 @@ class FollowUpManager(models.Manager):
         return self.filter(public=True)
 
 
-@python_2_unicode_compatible
 class FollowUp(models.Model):
     """
     A FollowUp is a comment and/or change to a ticket. We keep a simple
@@ -617,7 +614,6 @@ class FollowUp(models.Model):
         super(FollowUp, self).save(*args, **kwargs)
 
 
-@python_2_unicode_compatible
 class TicketChange(models.Model):
     """
     For each FollowUp, any changes to the parent ticket (eg Title, Priority,
@@ -681,7 +677,6 @@ def attachment_path(instance, filename):
     return os.path.join(path, filename)
 
 
-@python_2_unicode_compatible
 class Attachment(models.Model):
     """
     Represents a file attached to a follow-up. This could come from an e-mail
@@ -733,7 +728,6 @@ class Attachment(models.Model):
         verbose_name_plural = _('Attachments')
 
 
-@python_2_unicode_compatible
 class PreSetReply(models.Model):
     """
     We can allow the admin to define a number of pre-set replies, used to
@@ -776,7 +770,6 @@ class PreSetReply(models.Model):
         return '%s' % self.name
 
 
-@python_2_unicode_compatible
 class EscalationExclusion(models.Model):
     """
     An 'EscalationExclusion' lets us define a date on which escalation should
@@ -814,7 +807,6 @@ class EscalationExclusion(models.Model):
         verbose_name_plural = _('Escalation exclusions')
 
 
-@python_2_unicode_compatible
 class EmailTemplate(models.Model):
     """
     Since these are more likely to be changed than other templates, we store
@@ -875,7 +867,6 @@ class EmailTemplate(models.Model):
         verbose_name_plural = _('e-mail templates')
 
 
-@python_2_unicode_compatible
 class KBCategory(models.Model):
     """
     Lets help users help themselves: the Knowledge Base is a categorised
@@ -907,7 +898,6 @@ class KBCategory(models.Model):
         return reverse('helpdesk_kb_category', kwargs={'slug': self.slug})
 
 
-@python_2_unicode_compatible
 class KBItem(models.Model):
     """
     An item within the knowledgebase. Very straightforward question/answer
@@ -975,7 +965,6 @@ class KBItem(models.Model):
         return reverse('helpdesk_kb_item', args=[self.id])
 
 
-@python_2_unicode_compatible
 class SavedSearch(models.Model):
     """
     Allow a user to save a ticket search, eg their filtering and sorting
@@ -1022,7 +1011,6 @@ class SavedSearch(models.Model):
         verbose_name_plural = _('Saved searches')
 
 
-@python_2_unicode_compatible
 class UserSettings(models.Model):
     """
     A bunch of user-specific settings that we want to be able to define, such
@@ -1082,7 +1070,6 @@ def create_usersettings(sender, instance, created, **kwargs):
     models.signals.post_save.connect(create_usersettings, sender=settings.AUTH_USER_MODEL)
 
 
-@python_2_unicode_compatible
 class IgnoreEmail(models.Model):
     """
     This model lets us easily ignore e-mails from certain senders when
@@ -1161,7 +1148,6 @@ class IgnoreEmail(models.Model):
         verbose_name_plural = _('Ignored e-mail addresses')
 
 
-@python_2_unicode_compatible
 class TicketCC(models.Model):
     """
     Often, there are people who wish to follow a ticket who aren't the
@@ -1230,7 +1216,6 @@ class CustomFieldManager(models.Manager):
         return super(CustomFieldManager, self).get_queryset().order_by('ordering')
 
 
-@python_2_unicode_compatible
 class CustomField(models.Model):
     """
     Definitions for custom fields that are glued onto each ticket.
@@ -1341,7 +1326,6 @@ class CustomField(models.Model):
         verbose_name_plural = _('Custom fields')
 
 
-@python_2_unicode_compatible
 class TicketCustomFieldValue(models.Model):
     ticket = models.ForeignKey(
         Ticket,
@@ -1366,7 +1350,6 @@ class TicketCustomFieldValue(models.Model):
         verbose_name_plural = _('Ticket custom field values')
 
 
-@python_2_unicode_compatible
 class TicketDependency(models.Model):
     """
     The ticket identified by `ticket` cannot be resolved until the ticket in `depends_on` has been resolved.
@@ -1396,7 +1379,6 @@ class TicketDependency(models.Model):
         verbose_name_plural = _('Ticket dependencies')
 
 
-@python_2_unicode_compatible
 class QueueMembership(models.Model):
     """
     Used to restrict staff members to certain queues only
