@@ -1,13 +1,11 @@
-import os
+from builtins import str
 from datetime import datetime
 
-from django.forms.models import model_to_dict
 from django.db.models.fields import DateTimeField
 from django.db.models.fields.related import ManyToManyField, ForeignKey
-from django.contrib.contenttypes import generic
+from django.contrib.contenttypes.fields import GenericRelation
 from celery.task import Task
-from tendenci.core.perms.models import TendenciBaseModel
-from tendenci.core.exports.utils import render_csv
+from tendenci.apps.exports.utils import render_csv
 
 class InvoiceExportTask(Task):
     """Export Task for Celery
@@ -104,7 +102,7 @@ class InvoiceExportTask(Task):
                         value = ["%s" % obj for obj in f.value_from_object(item)]
                     if isinstance(f, ForeignKey):
                         value = getattr(item, f.name)
-                    if isinstance(f, generic.GenericRelation):
+                    if isinstance(f, GenericRelation):
                         generics = f.value_from_object(item).all()
                         value = ["%s" % obj for obj in generics]
                     if isinstance(f, DateTimeField):
@@ -119,7 +117,7 @@ class InvoiceExportTask(Task):
             data_row = []
             for field in fields:
                 # clean the derived values into unicode
-                value = unicode(d[field]).rstrip()
+                value = str(d[field]).rstrip()
                 data_row.append(value)
 
             data_row_list.append(data_row)
