@@ -3,7 +3,7 @@ from datetime import datetime
 from django import forms
 from django.contrib.admin import widgets
 from django.utils.safestring import mark_safe
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.urls import reverse
 
 # from captcha.fields import CaptchaField
