@@ -2,7 +2,7 @@ import datetime
 
 from django import forms
 from django.forms.widgets import SelectDateWidget
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.template.loader import render_to_string
 
 from tendenci.apps.emails.models import Email
@@ -15,7 +15,7 @@ from tendenci.apps.newsletters.models import (
     DAYS_CHOICES,
     INCLUDE_CHOICES
 )
-from tendenci.apps.perms.utils import get_groups_query_filters
+from tendenci.apps.perms.utils import get_query_filters, get_groups_query_filters
 from tendenci.apps.user_groups.models import Group
 
 EMAIL_SEARCH_CRITERIA_CHOICES = (
@@ -85,7 +85,11 @@ class OldGenerateForm(forms.ModelForm):
         
         default_groups = Group.objects.filter(status=True, status_detail="active")
         if not self.request.user.is_superuser:
-            filters = get_groups_query_filters(self.request.user,)
+
+            if get_setting('module', 'user_groups', 'permrequiredingd') == 'change':
+                filters = get_groups_query_filters(self.request.user,)
+            else:
+                filters = get_query_filters(self.request.user, 'user_groups.view_group', **{'perms_field': False})
             default_groups = default_groups.filter(filters).distinct()
         self.fields['group'].queryset = default_groups
 
