@@ -1,7 +1,7 @@
 # django
 from django.db import models
 from django.contrib.auth.models import User
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 class ThemeFileVersion(models.Model):
     file_name  = models.CharField(max_length=200, blank=False)
