@@ -1,4 +1,4 @@
-from django.core.management.base import BaseCommand, CommandError
+from django.core.management.base import BaseCommand
 
 
 class Command(BaseCommand):
@@ -23,4 +23,4 @@ class Command(BaseCommand):
                     ugroup.save()
                 if not ugroup.group:
                     # the save method will take care of the auth group.
-                    ugroup.save()
\ No newline at end of file
+                    ugroup.save()
